@@ -18,7 +18,7 @@ use crate::{
         ChunkId, Layout, LinkIdx, RowRange, StandardChunkId, StartIdx,
     },
     music::{Breakdown, MusicType, Score, StrokeSet},
-    utils::{FrontierItem, Rotation, RowCounts},
+    utils::{Counts, FrontierItem, Rotation},
     Query,
 };
 
@@ -77,7 +77,7 @@ pub struct Chunk {
     /// parts).  Optimisation passes can't change this
     total_length: TotalLength,
     /// The number of rows of each method generated by this chunk
-    method_counts: RowCounts,
+    method_counts: Counts,
     /// The music generated by this chunk in the composition.  Optimisation passes can't change this
     music: Breakdown,
 
@@ -330,7 +330,7 @@ impl Chunk {
         self.total_length.0
     }
 
-    pub fn method_counts(&self) -> &RowCounts {
+    pub fn method_counts(&self) -> &Counts {
         &self.method_counts
     }
 
@@ -693,7 +693,7 @@ fn build_chunk(
     // TODO: Determine how close to the ends of this chunk the music is generated?
     let non_duffer = music_types
         .iter()
-        .zip_eq(&music.counts)
+        .zip_eq(music.counts.as_slice())
         .any(|(music_type, count)| music_type.non_duffer() && *count > 0);
 
     Chunk {
